Learn R Programming

stops (version 1.9-1)

c_faithfulness: c-faithfulness calculates the c-faithfulness based on the index by Chen and Buja 2013 (M_adj) with equal input neigbourhoods

Description

c-faithfulness calculates the c-faithfulness based on the index by Chen and Buja 2013 (M_adj) with equal input neigbourhoods

Usage

c_faithfulness(confs, obsdiss, k = 3, ...)

Value

a numeric value; faithfulness

Arguments

confs

a numeric matrix or a dist object

obsdiss

a symmetric numeric matrix or a dist object. Must be supplied.

k

the number of nearest neighbours to be looked at

...

additional arguments passed to dist()

Examples

Run this code
delts<-smacof::kinshipdelta
dis<-smacofSym(delts)$confdist
c_faithfulness(dis,obsdiss=delts,k=3)

Run the code above in your browser using DataLab