c_hierarchy: c-hierarchy
captures how well a partition/ultrametric (obtained by hclust) explains the configuration distances. Uses variance explained for euclidean distances and deviance explained for everything else.
Description
c-hierarchy
captures how well a partition/ultrametric (obtained by hclust) explains the configuration distances. Uses variance explained for euclidean distances and deviance explained for everything else.
Usage
c_hierarchy(confs, voidarg = NULL, p = 2, agglmethod = "complete")
Value
a numeric value; hierarchy (see cl_validity)
Arguments
confs
a numeric matrix
voidarg
a placeholder to allow to pass NULL as strucpar and not interfere with the other arguments
p
the parameter of the Minokwski distances (p=2 euclidean and p=1 is manhattan)
agglmethod
the method used for creating the clustering, see hclust.