Free parameter is kappa=2r for the fitted distances.
stop_rstress(
dis,
theta = 1,
type = "ratio",
weightmat = NULL,
init = NULL,
ndim = 2,
itmaxi = 10000,
...,
stressweight = 1,
structures = c("cclusteredness", "clinearity", "cdependence", "cmanifoldness",
"cassociation", "cnonmonotonicity", "cfunctionality", "ccomplexity", "cfaithfulness",
"cregularity", "chierarchy", "cconvexity", "cstriatedness", "coutlying",
"cskinniness", "csparsity", "cstringiness", "cclumpiness", "cinequality"),
strucweight = rep(1/length(structures), length(structures)),
strucpars,
verbose = 0,
stoptype = c("additive", "multiplicative"),
registry = struc_reg
)A list with the components
stress: the stress-1 value
stress.m: default normalized stress
stoploss: the weighted loss value
indices: the values of the structuredness indices
parameters: the parameters used for fitting
fit: the returned object of the fitting procedure
stopobj: the stopobj object
numeric matrix or dist object of a matrix of proximities
the theta vector of powers; this must be a scalar of the kappa=2*r transformation for the fitted distances proximities. Defaults to 1. Note that what is returned is r, not kappa.
MDS type. Default is "ratio"
(optional) a matrix of nonnegative weights
(optional) initial configuration
number of dimensions of the target space
number of iterations.
additional arguments to be passed to the fitting procedure
weight to be used for the fit measure; defaults to 1
which structuredness indices to be included in the loss
weight to be used for the structuredness indices; ; defaults to 1/#number of structures
the parameters for the structuredness indices
numeric value hat prints information on the fitting process; >2 is extremely verbose
How to construct the target function for the multi objective optimization? Either 'additive' (default) or 'multiplicative'
registry object with c-structuredness indices.