The free parameter is lambda for power transformations the observed proximities. The fitted distances power is internally fixed to 1 and the power for the weights is 1.
stop_smacofSym(
dis,
theta = 1,
type = "ratio",
ndim = 2,
weightmat = 1 - diag(nrow(dis)),
init = NULL,
itmaxi = 1000,
...,
structures = c("cclusteredness", "clinearity", "cdependence", "cmanifoldness",
"cassociation", "cnonmonotonicity", "cfunctionality", "ccomplexity", "cfaithfulness",
"chierarchy", "cconvexity", "cstriatedness", "coutlying", "cskinniness", "csparsity",
"cstringiness", "cclumpiness", "cinequality"),
stressweight = 1,
strucweight = rep(1/length(structures), length(structures)),
strucpars,
verbose = 0,
stoptype = c("additive", "multiplicative"),
registry = struc_reg
)A list with the components
stress: the stress-1 (sqrt(stress.m))
stress.m: default normalized stress (used for STOPS)
stoploss: the weighted loss value
indices: the values of the structuredness indices
parameters: the parameters used for fitting (lambda)
fit: the returned object of the fitting procedure
stopobj: the stops object
numeric matrix or dist object of a matrix of proximities
the theta vector; must be a scalar for the lambda (proximity) transformation. Defaults to 1.
MDS type. Defaults ot 'ratio'.
number of dimensions of the target space
(optional) a matrix of nonnegative weights
(optional) initial configuration
number of iterations
additional arguments to be passed to the fitting
which structuredness indices to be included in the loss
weight to be used for the fit measure; defaults to 1
weight to be used for the structuredness indices; ; defaults to 1/#number of structures
the parameters for the structuredness indices
numeric value hat prints information on the fitting process; >2 is extremely verbose
How to construct the target function for the multi objective optimization? Either 'additive' (default) or 'multiplicative'
registry object with c-structuredness indices.