Free parameter is lambda for the observed proximities. Fitted distances are transformed with power 2, weights have exponent of 1. Note that the lambda here works as a multiplicator of 2 (as sstress has f(delta^2)).
stop_sstress(
dis,
theta = 1,
type = type,
weightmat = 1 - diag(nrow(dis)),
init = NULL,
ndim = 2,
itmaxi = 1e+05,
...,
stressweight = 1,
structures = c("cclusteredness", "clinearity", "cdependence", "cmanifoldness",
"cassociation", "cnonmonotonicity", "cfunctionality", "ccomplexity", "cfaithfulness",
"cregularity", "chierarchy", "cconvexity", "cstriatedness", "coutlying",
"cskinniness", "csparsity", "cstringiness", "cclumpiness", "cinequality"),
strucweight = rep(1/length(structures), length(structures)),
strucpars,
verbose = 0,
stoptype = c("additive", "multiplicative"),
registry = struc_reg
)A list with the components
stress: the stress-1 value
stress.m: default normalized stress
stoploss: the weighted loss value
indices: the values of the structuredness indices
parameters: the parameters used for fitting (lambda)
fit: the returned object of the fitting procedure
stopobj: the stopobj object
numeric matrix or dist object of a matrix of proximities
the theta vector of powers; this must be a scalar of the lambda transformation for the observed proximities. Defaults to 1. Note that the lambda here works as a multiplicator of 2 (as sstress has f(delta^2)).
MDS type.
(optional) a matrix of nonnegative weights
(optional) initial configuration
the number of dimensions of the target space
number of iterations
additional arguments to be passed to the fitting procedure
weight to be used for the fit measure; defaults to 1
which structuredness indices to be included in the loss
weight to be used for the structuredness indices; ; defaults to 1/#number of structures
the parameters for the structuredness indices
numeric value hat prints information on the fitting process; >2 is extremely verbose
How to construct the target function for the multi objective optimization? Either 'additive' (default) or 'multiplicative'
registry object with c-structuredness indices.