powered by
c-faithfulness calculates the c-faithfulness based on the index by Chen and Buja 2013 (M_adj) with equal input neigbourhoods
c_faithfulness(confs, obsdiss, k = 3, ...)
a numeric value; faithfulness
a numeric matrix or a dist object
a symmetric numeric matrix or a dist object. Must be supplied.
the number of nearest neighbours to be looked at
additional arguments passed to dist()
delts<-smacof::kinshipdelta dis<-smacofSym(delts)$confdist c_faithfulness(dis,obsdiss=delts,k=3)
Run the code above in your browser using DataLab