match_partial_ignorecase_nopunct: function for lookup that partially matched and ignores cases and punctuation
Description
function for lookup that partially matched and ignores cases and punctuation
Usage
match_partial_ignorecase_nopunct(lookup, entry, ...)
Arguments
- lookup
the lookup string
- entry
the registry entry
- ...
additional arguments to pmatch